import { type ObjectEntries } from 'valibot';
import { type Thing } from './Thing';
export declare const definedTerm: <TEntries extends ObjectEntries>(entries?: TEntries | undefined) => any;
/**
 * A word, name, acronym, phrase, etc. with a formal definition. Often used in the context of category or subject classification, glossaries or dictionaries, product or creative work types, etc. Use the name property for the term being defined, use termCode if the term has an alpha-numeric code allocated, use description to provide the definition of the term.
 *
 * This is partial implementation of https://schema.org/DefinedTerm.
 *
 * @see https://schema.org/DefinedTerm
 */
export type DefinedTerm = Thing & {
    /**
     * A [DefinedTermSet](https://schema.org/DefinedTermSet) that contains this term.
     *
     * @see https://schema.org/inDefinedTermSet
     */
    inDefinedTermSet?: string | undefined;
    /**
     * A code that identifies this [DefinedTerm](https://schema.org/DefinedTerm) within a [DefinedTermSet](https://schema.org/DefinedTermSet).
     *
     * @see https://schema.org/termCode
     */
    termCode?: string | undefined;
};
export declare const parseDefinedTerm: (data: unknown) => DefinedTerm;
//# sourceMappingURL=DefinedTerm.d.ts.map